@@ -28,11 +28,15 @@
 #define TAB_LABEL_DIRECT "Direct"
 #define TAB_LABEL_EXTENT "Extent"
 
-/* maemo5 currently has no maemo mapper */
-#if defined(USE_HILDON) && (MAEMO_VERSION_MAJOR < 5)
+/* maemo5 just got maemo mapper */
+#if defined(USE_HILDON)
 #define HAS_MAEMO_MAPPER
+#ifdef FREMANTLE
+#define TAB_LABEL_MM     "M.Mapper"
+#else
 #define TAB_LABEL_MM     "Maemo Mapper"
 #endif
+#endif
 
 /* limit of square kilometers above the warning is enabled */
 #define WARN_OVER  5.0
@@ -743,7 +747,7 @@ gboolean area_edit(area_edit_t *area) {
 
   vbox = gtk_vbox_new(FALSE, 8);
   context.mmapper.fetch = 
-    gtk_button_new_with_label(_("Get from Maemo Mapper"));
+    button_new_with_label(_("Get from Maemo Mapper"));
   gtk_box_pack_start(GTK_BOX(vbox), context.mmapper.fetch, FALSE, FALSE, 0);
 
   g_signal_connect(G_OBJECT(context.mmapper.fetch), "clicked",
@@ -753,8 +757,7 @@ gboolean area_edit(area_edit_t *area) {
   label = gtk_label_new(_("(recommended MM zoom level < 7)"));
   gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
 
-
-  notebook_append_page(context.notebook, vbox, gtk_label_new(_(TAB_LABEL_MM)));
+  notebook_append_page(context.notebook, vbox, _(TAB_LABEL_MM));
 #endif
 
   /* ------------------------------------------------------ */
