@@ -20,7 +20,6 @@
 #include "appdata.h"
 
 #include <curl/curl.h>
-#include <curl/types.h> /* new for v7 */
 #include <curl/easy.h>  /* new for v7 */
 #include <unistd.h>
 
@@ -225,6 +224,8 @@ static void *worker_thread(void *ptr) {
 
     if(ok) {
       curl_easy_setopt(curl, CURLOPT_URL, request->url);
+
+    curl_easy_setopt(curl, CURLOPT_IPRESOLVE, CURL_IPRESOLVE_V4);
       
       switch(request->type) {
       case NET_IO_DL_FILE:
