@@ -157,7 +157,6 @@ tag_t *osm_parse_osm_tag(osm_t *osm, xmlDocPtr doc, xmlNode *a_node) {
 
 gboolean osm_is_creator_tag(tag_t *tag) {
   if(strcasecmp(tag->key, "created_by") == 0) return TRUE;
-  if(strcasecmp(tag->key, "source") == 0) return TRUE;
 
   return FALSE;
 }
@@ -371,7 +370,7 @@ node_chain_t *osm_parse_osm_way_nd(osm_t *osm,
   char *prop;
 
   if((prop = (char*)xmlGetProp(a_node, (unsigned char*)"ref"))) {
-    item_id_t id = strtoul(prop, NULL, 10);
+    item_id_t id = strtoll(prop, NULL, 10);
     node_chain_t *node_chain = g_new0(node_chain_t, 1);
 
     /* search matching node */
@@ -487,7 +486,7 @@ member_t *osm_parse_osm_relation_member(osm_t *osm,
   }
 
   if((prop = (char*)xmlGetProp(a_node, (unsigned char*)"ref"))) {
-    item_id_t id = strtoul(prop, NULL, 10);
+    item_id_t id = strtoll(prop, NULL, 10);
 
     switch(member->object.type) {
     case ILLEGAL:
@@ -716,7 +715,7 @@ static node_t *process_node(xmlTextReaderPtr reader, osm_t *osm) {
 
   char *prop;
   if((prop = (char*)xmlTextReaderGetAttribute(reader, BAD_CAST "id"))) {
-    OSM_ID(node) = strtoul(prop, NULL, 10);
+    OSM_ID(node) = strtoll(prop, NULL, 10);
     xmlFree(prop);
   }
 
@@ -795,7 +794,7 @@ static node_chain_t *process_nd(xmlTextReaderPtr reader, osm_t *osm) {
   char *prop;
 
   if((prop = (char*)xmlTextReaderGetAttribute(reader, BAD_CAST "ref"))) {
-    item_id_t id = strtoul(prop, NULL, 10);
+    item_id_t id = strtoll(prop, NULL, 10);
     node_chain_t *node_chain = g_new0(node_chain_t, 1);
     
     /* search matching node */
@@ -819,7 +818,7 @@ static way_t *process_way(xmlTextReaderPtr reader, osm_t *osm) {
 
   char *prop;
   if((prop = (char*)xmlTextReaderGetAttribute(reader, BAD_CAST "id"))) {
-    OSM_ID(way) = strtoul(prop, NULL, 10);
+    OSM_ID(way) = strtoll(prop, NULL, 10);
     xmlFree(prop);
   }
 
@@ -899,7 +898,7 @@ static member_t *process_member(xmlTextReaderPtr reader, osm_t *osm) {
   }
 
   if((prop = (char*)xmlTextReaderGetAttribute(reader, BAD_CAST "ref"))) {
-    item_id_t id = strtoul(prop, NULL, 10);
+    item_id_t id = strtoll(prop, NULL, 10);
 
     switch(member->object.type) {
     case ILLEGAL:
@@ -956,7 +955,7 @@ static relation_t *process_relation(xmlTextReaderPtr reader, osm_t *osm) {
 
   char *prop;
   if((prop = (char*)xmlTextReaderGetAttribute(reader, BAD_CAST "id"))) {
-    OSM_ID(relation) = strtoul(prop, NULL, 10);
+    OSM_ID(relation) = strtoll(prop, NULL, 10);
     xmlFree(prop);
   }
 
@@ -1291,7 +1290,7 @@ static char *osm_generate_xml(osm_t *osm, item_id_t changeset,
 	snprintf(str, sizeof(str), ITEM_ID_FORMAT, OSM_ID(node));
 	xmlNewProp(node_node, BAD_CAST "id", BAD_CAST str);
       }
-      snprintf(str, sizeof(str), "%u", OSM_VERSION(node));
+      snprintf(str, sizeof(str), "%u", (unsigned)OSM_VERSION(node));
       xmlNewProp(node_node, BAD_CAST "version", BAD_CAST str);
       snprintf(str, sizeof(str), "%u", (unsigned)changeset);
       xmlNewProp(node_node, BAD_CAST "changeset", BAD_CAST str);
@@ -1309,7 +1308,7 @@ static char *osm_generate_xml(osm_t *osm, item_id_t changeset,
       xmlNodePtr way_node = xmlNewChild(root_node, NULL, BAD_CAST "way", NULL);
       snprintf(str, sizeof(str), ITEM_ID_FORMAT, OSM_ID(way));
       xmlNewProp(way_node, BAD_CAST "id", BAD_CAST str);
-      snprintf(str, sizeof(str), "%u", OSM_VERSION(way));
+      snprintf(str, sizeof(str), "%u", (unsigned)OSM_VERSION(way));
       xmlNewProp(way_node, BAD_CAST "version", BAD_CAST str);
       snprintf(str, sizeof(str), "%u", (unsigned)changeset);
       xmlNewProp(way_node, BAD_CAST "changeset", BAD_CAST str);
@@ -1334,7 +1333,7 @@ static char *osm_generate_xml(osm_t *osm, item_id_t changeset,
 					BAD_CAST "relation", NULL);
       snprintf(str, sizeof(str), ITEM_ID_FORMAT, OSM_ID(relation));
       xmlNewProp(rel_node, BAD_CAST "id", BAD_CAST str);
-      snprintf(str, sizeof(str), "%u", OSM_VERSION(relation));
+      snprintf(str, sizeof(str), "%u", (unsigned)OSM_VERSION(relation));
       xmlNewProp(rel_node, BAD_CAST "version", BAD_CAST str);
       snprintf(str, sizeof(str), "%u", (unsigned)changeset);
       xmlNewProp(rel_node, BAD_CAST "changeset", BAD_CAST str);
