@@ -20,7 +20,6 @@
 #include "appdata.h"
 
 #include <curl/curl.h>
-#include <curl/types.h> /* new for v7 */
 #include <curl/easy.h> /* new for v7 */
 #include <unistd.h>
 
@@ -256,6 +255,8 @@ static gboolean osm_update_item(struct log_s *log, char *xml_str,
     /* specify target URL, and note that this URL should include a file
        name, not only a directory */
     curl_easy_setopt(curl, CURLOPT_URL, url);
+
+	curl_easy_setopt(curl, CURLOPT_IPRESOLVE, CURL_IPRESOLVE_V4);
     
     /* now specify which file to upload */
     curl_easy_setopt(curl, CURLOPT_READDATA, &read_data);
@@ -309,7 +310,7 @@ static gboolean osm_update_item(struct log_s *log, char *xml_str,
 	      response, osm_http_message(response));
     else {
       if(!id) appendf(log, COLOR_OK, _("ok\n"));
-      else    appendf(log, COLOR_OK, _("ok: #%ld\n"), *id);
+      else    appendf(log, COLOR_OK, _("ok: #"ITEM_ID_FORMAT"\n"), *id);
     }
     
     /* if it's neither "ok" (200), nor "internal server error" (500) */
@@ -382,6 +383,8 @@ static gboolean osm_delete_item(struct log_s *log, char *xml_str,
     /* specify target URL, and note that this URL should include a file
        name, not only a directory */
     curl_easy_setopt(curl, CURLOPT_URL, url);
+
+	curl_easy_setopt(curl, CURLOPT_IPRESOLVE, CURL_IPRESOLVE_V4);
     
     /* some servers don't like requests that are made without a user-agent
        field, so we provide one */
@@ -519,7 +522,7 @@ static void osm_upload_nodes(osm_upload_context_t *context) {
       } else {
 	url = g_strdup_printf("%s/node/" ITEM_ID_FORMAT, 
 			      project->server, OSM_ID(node));
-	appendf(&context->log, NULL, _("Modified node #%ld "), OSM_ID(node));
+	appendf(&context->log, NULL, _("Modified node #"ITEM_ID_FORMAT" "), OSM_ID(node));
       }
 
       /* upload this node */
@@ -597,7 +600,7 @@ static void osm_upload_ways(osm_upload_context_t *context) {
       } else {
 	url = g_strdup_printf("%s/way/" ITEM_ID_FORMAT, 
 			      project->server, OSM_ID(way));
-	appendf(&context->log, NULL, _("Modified way #%ld "), OSM_ID(way));
+	appendf(&context->log, NULL, _("Modified way #"ITEM_ID_FORMAT" "), OSM_ID(way));
       }
       
       /* upload this node */
@@ -676,7 +679,7 @@ static void osm_upload_relations(osm_upload_context_t *context) {
       } else {
 	url = g_strdup_printf("%s/relation/" ITEM_ID_FORMAT, 
 			      project->server,OSM_ID(relation));
-	appendf(&context->log, NULL, _("Modified relation #%ld "), 
+	appendf(&context->log, NULL, _("Modified relation #"ITEM_ID_FORMAT" "),
 		OSM_ID(relation));
       }
       
